@@ -1,13 +1,6 @@
-import os
-import json
-import time
-import queue
+import os, json, time, queue, inspect, functools, sys, signal
 from _collections import defaultdict
-import inspect
-import functools
-import sys
 from enum import Enum, unique
-import signal
 
 
 def is_Windows():
@@ -510,19 +503,34 @@ class Timer(_DecoratorContextManager):
         
     def __enter__(self):
         self.start = time.time()
-        
-    def __exit__(self, *_): 
+
+    @property
+    def HHmmss(self):
         lapse = time.time() - self.start
+        seconds = lapse % 60
+        minutes = int(lapse // 60)
+        if minutes > 0:
+            hours = minutes // 60
+            if hours > 0:
+                minutes %= 60
+                return "%02d:%02d:%02d" % (hours, minutes, seconds)
+            
+            return "%02d:%02d" % (minutes, seconds)
+        
+        return "%.2f seconds" % seconds
+
+    def __exit__(self, *_): 
         if self.message:
-            msg = f'time cost for {self.message} is %.2f seconds' % lapse
+            msg = f'time cost for {self.message} is %s' % self.HHmmss
         else:
-            msg = 'time cost is %.2f seconds' % lapse
+            msg = 'time cost is %s' % self.HHmmss
             
         if self.logger:
             self.logger.info(msg)
         else:
             print(msg)
 
+
 class Timeout:
     """Timeout class using ALARM signal."""
     def __init__(self, sec):
@@ -743,6 +751,7 @@ def fromEntries(*args, object=True):
 
     return obj
 
+
 def array_split(arr, index):
     if isinstance(index, int):
         return arr[:index], arr[index:]
@@ -768,6 +777,8 @@ def array_split(arr, index):
                 rest = arr[:start] + type(arr)(rest) + arr[stop:]
             else:
                 rest = arr[:start] + arr[stop:]
+                
+            return arr[index], rest
         else:
             if start is None:
                 start = len(arr) - 1
@@ -785,7 +796,7 @@ def array_split(arr, index):
             else:
                 rest = arr[:stop + 1] + arr[start + 1:]
 
-        return arr[index], rest
+            return rest, arr[index] 
 
 
 if __name__ == '__main__':
