@@ -103,14 +103,14 @@ class Text:
                         break
         else:
             self.rewind()
-            offset = self.f.tell()
+            offset = self.file.tell()
             while index > 0:
                 index -= 1
                 while True:
                     offset += 1
-                    _offset = self.f.seek(offset, os.SEEK_SET)
+                    _offset = self.file.seek(offset, os.SEEK_SET)
                     assert _offset == offset
-                    char = self.f.read(1)
+                    char = self.file.read(1)
 #                     print('char =', char)
                     if char[0] == '\n' or char[0] == '\r':
                         break
@@ -135,36 +135,36 @@ class Text:
         if index < 0:
             self.end()
             index = -index
-            offset = self.f.tell() - 1
+            offset = self.file.tell() - 1
             while index > 0:
                 index -= 1
                 offset -= 1
                 while True:
                     offset -= 1
-                    _offset = self.f.seek(offset, os.SEEK_SET)
+                    _offset = self.file.seek(offset, os.SEEK_SET)
                     assert _offset == offset
-                    char = self.f.read(1)
+                    char = self.file.read(1)
     #                     print('char =', char)
                     if char == '\n' or char == '\r':
                         break
         else:
             self.rewind()
-            offset = self.f.tell()
+            offset = self.file.tell()
             while index > 0:
                 index -= 1
                 while True:
                     offset += 1
-                    _offset = self.f.seek(offset, os.SEEK_SET)
+                    _offset = self.file.seek(offset, os.SEEK_SET)
                     assert _offset == offset
-                    char = self.f.read(1)
+                    char = self.file.read(1)
 #                     print('char =', char)
                     if char == '\n' or char == '\r':
                         break
-        current_pos = self.f.tell()
+        current_pos = self.file.tell()
 
-        self.f.seek(current_pos, os.SEEK_SET)
+        self.file.seek(current_pos, os.SEEK_SET)
 
-        return self.f.readline().strip()
+        return self.file.readline().strip()
 
     def write(self, s):
         self.rewind()
@@ -188,7 +188,7 @@ class Text:
         self.file.seek(0, os.SEEK_SET)
         byteOrderMark = self.file.read(1)
         if byteOrderMark and ord(byteOrderMark) != 0xFEFF:
-            self.file.seek(0, os.SEEK_SET)        
+            self.file.seek(0, os.SEEK_SET)
 
     def end(self):
         self.file.seek(0, os.SEEK_END)
@@ -247,7 +247,8 @@ class Text:
         char = self.file.read(size)        
         return char == end
 
-    def readlines(self): 
+    def readlines(self):
+        self.rewind()
         return [s for s in self]
     
     def readline(self):
@@ -301,7 +302,8 @@ class GzipFile:
         return self
 
     def __next__(self):
-        if line := self.file.readline():
+        line = self.file.readline()
+        if line:
             return json.loads(line) if self.json else line
 
         raise StopIteration
